Changelog
=========

0.0.5
-----

- Read config from source flask app

0.0.4
-----

- Get config with default value

0.0.3
-----

- Log all request by default

0.0.2
-----

- Test with different user case

0.0.1
-----

- Initial public release
